package com.gic.enterprise.service.outer;

import com.gic.api.base.commons.ServiceResponse;
import com.gic.commons.util.EntityUtil;
import com.gic.enterprise.constant.EnterpriseStatusTypeEnum;
import com.gic.enterprise.dto.EnterpriseDTO;
import com.gic.enterprise.entity.TabEnterprise;
import com.gic.enterprise.error.ErrorCode;
import com.gic.enterprise.service.EnterpriseApiService;
import com.gic.enterprise.service.EnterpriseService;
import com.gic.store.utils.valid.ValidUtil;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.Date;

/**
 * @author guojx
 * @date 2019/7/16 4:33 PM
 */
@Service("enterpriseApiService")
public class EnterpriseApiServiceImpl implements EnterpriseApiService {
    @Autowired
    private EnterpriseService enterpriseService;

    @Override
    public ServiceResponse<Integer> saveEnterprise(EnterpriseDTO enterpriseDTO) {
        //valid param
        ServiceResponse paramResult = ValidUtil.allCheckValidate(enterpriseDTO, EnterpriseDTO.SaveEnterpriseValid.class);
        if (!paramResult.isSuccess()) {
            return paramResult;
        }
        if (enterpriseService.isRepeatEnterpriseName(enterpriseDTO.getEnterpriseName(), null)) {
            ServiceResponse.failure(ErrorCode.PARAMETER_ERROR.getCode(), "商户名称不能重复");
        }

        enterpriseDTO.setCreateTime(new Date());
        enterpriseDTO.setUpdateTime(new Date());
        enterpriseDTO.setIsInitComplete(0);
        enterpriseDTO.setStatus(EnterpriseStatusTypeEnum.EFFECTIVE.getCode());

        int enterpriseId = enterpriseService.saveEnterprise(enterpriseDTO);
        //todo 新增商户初始化配置信息
        return ServiceResponse.success(enterpriseId);
    }

    @Override
    public ServiceResponse<Integer> editEnterprise(EnterpriseDTO enterpriseDTO) {
        //valid param
        ServiceResponse paramResult = ValidUtil.allCheckValidate(enterpriseDTO,
                EnterpriseDTO.SaveEnterpriseValid.class, EnterpriseDTO.EditEnterpriseValid.class);
        if (!paramResult.isSuccess()) {
            return paramResult;
        }
        TabEnterprise tabEnterprise = enterpriseService.getEnterpriseById(enterpriseDTO.getEnterpriseId());
        if (tabEnterprise == null) {
            ServiceResponse.failure(ErrorCode.PARAMETER_ERROR.getCode(), "企业ID错误，查询不到数据");
        }
        if (enterpriseService.isRepeatEnterpriseName(enterpriseDTO.getEnterpriseName(), enterpriseDTO.getEnterpriseId())) {
            ServiceResponse.failure(ErrorCode.PARAMETER_ERROR.getCode(), "商户名称不能重复");
        }

        enterpriseDTO.setUpdateTime(new Date());
        enterpriseService.editEnterprise(enterpriseDTO);
        return ServiceResponse.success();
    }

    @Override
    public ServiceResponse<EnterpriseDTO> getEnterpriseById(Integer enterpriseId) {
        TabEnterprise tabEnterprise = enterpriseService.getEnterpriseById(enterpriseId);
        if (tabEnterprise == null) {
            ServiceResponse.failure(ErrorCode.PARAMETER_ERROR.getCode(), "商户ID输入有误");
        }
        return ServiceResponse.success(EntityUtil.changeEntityNew(EnterpriseDTO.class, tabEnterprise));
    }

    @Override
    public ServiceResponse disableEnterprise(Integer enterpriseId) {
        TabEnterprise tabEnterprise = enterpriseService.getEnterpriseById(enterpriseId);
        if (tabEnterprise == null) {
            ServiceResponse.failure(ErrorCode.PARAMETER_ERROR.getCode(), "商户ID输入有误");
        }
        enterpriseService.changeEnterpriseStatus(enterpriseId, EnterpriseStatusTypeEnum.DISABLE.getCode());
        return ServiceResponse.success();
    }

    @Override
    public ServiceResponse enableEnterprise(Integer enterpriseId) {
        TabEnterprise tabEnterprise = enterpriseService.getEnterpriseById(enterpriseId);
        if (tabEnterprise == null) {
            ServiceResponse.failure(ErrorCode.PARAMETER_ERROR.getCode(), "商户ID输入有误");
        }
        enterpriseService.changeEnterpriseStatus(enterpriseId, EnterpriseStatusTypeEnum.EFFECTIVE.getCode());
        return ServiceResponse.success();
    }
}
