package com.gic.operation.web.controller;

import com.gic.api.base.commons.ServiceResponse;
import com.gic.auth.constant.UserConstants;
import com.gic.auth.dto.UserDTO;
import com.gic.auth.exception.StoreException;
import com.gic.auth.service.UserApiService;
import com.gic.commons.webapi.reponse.RestResponse;
import com.gic.enterprise.dto.EnterpriseDTO;
import com.gic.enterprise.error.ErrorCode;
import com.gic.enterprise.response.EnterpriseRestResponse;
import com.gic.enterprise.service.EnterpriseApiService;
import com.gic.operation.web.utils.UserPasswordUtil;
import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

/**
 * @author guojx
 * @date 2019/7/17 10:32 AM
 */
@RestController
@RequestMapping("/enterprise")
public class EnterpriseController {
    private static final Logger LOGGER = LoggerFactory.getLogger(EnterpriseController.class);
    @Autowired
    private EnterpriseApiService enterpriseApiService;
    @Autowired
    private UserApiService userApiService;

    @RequestMapping("/save-enterprise")
    @Transactional(rollbackFor = Exception.class)
    public RestResponse saveEnterprise(@Validated({EnterpriseDTO.SaveEnterpriseValid.class}) EnterpriseDTO enterpriseDTO,
                                       @Validated({UserDTO.UserQoValid.class}) UserDTO userDTO) {
        ServiceResponse<Integer> enterpriseResult = enterpriseApiService.saveEnterprise(enterpriseDTO);
        if (enterpriseResult.isSuccess()) {
            int enterpriseId = enterpriseResult.getResult();
            userDTO.setEnterpriseId(enterpriseId);
            int passwordType = userDTO.getPasswordType();
            String password;
            //加密
            if (UserConstants.CREATE_AUTO == passwordType) {
                //自动随机生成
                password = UserPasswordUtil.createPasswordAuto();
            } else {
                if (StringUtils.isNotBlank(userDTO.getPassword()) && userDTO.getPassword().equals(userDTO.getConfirmPassword())) {
                    //如果一致
                    password = userDTO.getPassword();
                } else {
                    return RestResponse.failure(ErrorCode.PARAMETER_ERROR.getCode(), "密码不一致");
                }
            }
            userDTO.setPassword(UserPasswordUtil.getEncryptPassword(password));
            //超级管理员
            userDTO.setSuperAdmin(1);
            //新增
            ServiceResponse userResult = userApiService.saveUser(userDTO);
            if (userResult.isSuccess()) {
                //todo 发送短信（如果是自动生成密码）
                return RestResponse.success();
            } else {
                //回滚
                throw new StoreException(userResult.getCode(), userResult.getMessage());
            }
        } else {
            return EnterpriseRestResponse.failure(enterpriseResult);
        }
    }

    @RequestMapping("/edit-enterprise")
    public RestResponse editEnterprise(@Validated({EnterpriseDTO.EditEnterpriseValid.class, EnterpriseDTO.SaveEnterpriseValid.class})
            EnterpriseDTO enterpriseDTO) {
        ServiceResponse enterpriseResult = enterpriseApiService.saveEnterprise(enterpriseDTO);
        if (enterpriseResult.isSuccess()) {
            return RestResponse.success();
        } else {
            return EnterpriseRestResponse.failure(enterpriseResult);
        }
    }

    @RequestMapping("/get-enterprise")
    public RestResponse editEnterprise(Integer enterpriseId) {
        ServiceResponse enterpriseResult = enterpriseApiService.getEnterpriseById(enterpriseId);
        if (enterpriseResult.isSuccess()) {
            return RestResponse.success();
        } else {
            return EnterpriseRestResponse.failure(enterpriseResult);
        }
    }

    @RequestMapping("/enable-enterprise")
    public RestResponse enableEnterprise(Integer enterpriseId) {
        ServiceResponse enterpriseResult = enterpriseApiService.enableEnterprise(enterpriseId);
        if (enterpriseResult.isSuccess()) {
            return RestResponse.success();
        } else {
            return EnterpriseRestResponse.failure(enterpriseResult);
        }
    }

    @RequestMapping("/disable-enterprise")
    public RestResponse disableEnterprise(Integer enterpriseId) {
        ServiceResponse enterpriseResult = enterpriseApiService.disableEnterprise(enterpriseId);
        if (enterpriseResult.isSuccess()) {
            return RestResponse.success();
        } else {
            return EnterpriseRestResponse.failure(enterpriseResult);
        }
    }
}
