package com.gic.operation.web.controller;

import com.gic.api.base.commons.ServiceResponse;
import com.gic.auth.constant.UserConstants;
import com.gic.auth.dto.UserDTO;
import com.gic.auth.service.UserApiService;
import com.gic.commons.webapi.reponse.RestResponse;
import com.gic.enterprise.error.ErrorCode;
import com.gic.enterprise.response.EnterpriseRestResponse;
import com.gic.operation.web.utils.UserPasswordUtil;
import com.gic.store.constant.StoreGroupConstant;
import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

/**
 * @author guojx
 * @date 2019/7/17 11:26 AM
 */
@RestController
@RequestMapping("/user")
public class UserController {
    private static final Logger LOGGER = LoggerFactory.getLogger(UserController.class);
    @Autowired
    private UserApiService userApiService;

    @RequestMapping("/save-or-update-user")
    public RestResponse editUser(@Validated({UserDTO.UserQoValid.class}) UserDTO userDTO) {
        userDTO.setEnterpriseId(StoreGroupConstant.TEST_ENTERPRISE_ID);
        int passwordType = userDTO.getPasswordType();
        String password;
        //加密
        if (UserConstants.CREATE_AUTO == passwordType) {
            //自动随机生成
            password = UserPasswordUtil.createPasswordAuto();
        } else {
            if (StringUtils.isNotBlank(userDTO.getPassword()) && userDTO.getPassword().equals(userDTO.getConfirmPassword())) {
                //如果一致
                password = userDTO.getPassword();
            } else {
                return RestResponse.failure(ErrorCode.PARAMETER_ERROR.getCode(), "密码不一致");
            }
        }
        userDTO.setPassword(UserPasswordUtil.getEncryptPassword(password));
        ServiceResponse userResult;
        if (userDTO.getUserId() == null) {
            userResult = userApiService.saveUser(userDTO);
        } else {
            userResult = userApiService.editUser(userDTO);
        }
        if (userResult.isSuccess()) {
            return RestResponse.success();
        } else {
            return EnterpriseRestResponse.failure(userResult);
        }
    }

    @RequestMapping("/get-user")
    public RestResponse getUser(Integer userId) {
        ServiceResponse enterpriseResult = userApiService.getUserById(userId);
        if (enterpriseResult.isSuccess()) {
            return RestResponse.success();
        } else {
            return EnterpriseRestResponse.failure(enterpriseResult);
        }
    }
}
